# Generated by roxygen2: do not edit by hand

export(expected_genotype_dist)
export(genotype_freq)
export(genotype_prob)
export(haldane_map)
export(joint_map)
export(permutation_test)
export(pheno_stats)
export(skeletion_build)
export(skeleton_build)
importFrom(StepReg,stepwise)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,df.residual)
importFrom(stats,lm)
importFrom(stats,predict)
importFrom(stats,resid)
importFrom(stats,shapiro.test)
importFrom(stats,terms)
importFrom(stats,update)
